@@ -260,8 +260,10 @@ class AssetData:
     def md5sum_of_file(self):
         with self.file_path.open("rb") as file_:
             md5sum = hashlib.md5()
-            while chunk := file_.read(8192):
+            chunk = file_.read(8192)
+            while chunk:
                 md5sum.update(chunk)
+                chunk = file_.read(8192)
             return md5sum.hexdigest().encode()
 
     @classmethod
@@ -354,4 +356,4 @@ class AssetData:
             path = self.file_path
 
         with path.open("rb") as file_:
-            return file_.read()
\ No newline at end of file
+            return file_.read()
